@@ -1,28 +1,17 @@
 # -*- coding: UTF-8 -*-
-'''
-@作者  ：B站/抖音/微博/小红书/公众号，都叫：程序员晚枫，微信：CoderWanFeng
-@读者群     ：http://www.python4office.cn/wechat-group/
-@学习网站      ：https://www.python-office.com
-@代码日期    ：2023/8/22 23:28
-'''
 import poimage
 
-# @except_dec()
-from office.lib.decorator_utils.instruction_url import instruction
-
 
 def compress_image(input_file: str, output_file: str, quality: int):
     poimage.compress_image(input_file, output_file, quality)
 
 
-# @instruction
 def image2gif():
     poimage.image2gif()
 
 
 # todo：输出文件路径
-# @except_dec()
-# @instruction
+
 def add_watermark(file, mark, output_path='./', color="#eaeaea", size=30, opacity=0.35, space=200,
                   angle=30):
     """
@@ -45,31 +34,25 @@ def add_watermark(file, mark, output_path='./', color="#eaeaea", size=30, opacit
 
 
 # todo：输入文件路径
-# @except_dec()
-# @instruction
+
 def img2Cartoon(path, client_api='OVALewIvPyLmiNITnceIhrYf', client_secret='rpBQH8WuXP4ldRQo5tbDkv3t0VgzwvCN'):
     poimage.img2Cartoon(path, client_api, client_secret)
     # mainImage.img2Cartoon(path, client_api, client_secret)
 
 
-# @except_dec()
-# @instruction
 def down4img(url, output_path='.', output_name='down4img', type='jpg'):
     poimage.down4img(url, output_path, output_name, type)
     # mainImage.down4img(url, output_name, type)
 
 
-# @instruction
 def txt2wordcloud(filename, color="white", result_file="your_wordcloud.png"):
     poimage.txt2wordcloud(filename, color, result_file)
 
 
-# @instruction
 def pencil4img(input_img, output_path='./', output_name='pencil4img.jpg'):
     poimage.pencil4img(input_img, output_path, output_name)
 
 
-# @instruction
 def decode_qrcode(qrcode_path):
     """
     解析二维码
@@ -79,6 +62,5 @@ def decode_qrcode(qrcode_path):
     poimage.decode_qrcode(qrcode_path)
 
 
-# @instruction
 def del_watermark(input_image, output_image=r'./del_water_mark.jpg'):
     poimage.del_watermark(input_image, output_image)
